package main

import (
	"bufio"
	"encoding/binary"
	"os"
	"strconv"
)

func main() {
	print("starting msuthing\n")
	if len(os.Args) != 4 {
		print("usage:\n\n\t" + os.Args[0] + " <inputAudioFile.wav> <loopPoint integer> <outputPCMFile.pcm>\n\tuse \"0\" for no loop point\n\n")
		return
	}
	inFile, err := os.Open(os.Args[1])
	if err != nil {
		print("problem opening " + os.Args[1] + "\n")
		return
	}
	loopPoint, err := strconv.Atoi(os.Args[2])
	if err != nil {
		print("problem parsing " + os.Args[2] + " as loop point" + "\n")
		return
	}
	loopPoint32 := uint32(loopPoint)
	outFile, err := os.Create(os.Args[3])
	defer outFile.Close()
	if err != nil {
		print("problem creating file " + os.Args[3] + "\n")
		return
	}
	outFileWriter := bufio.NewWriter(outFile)
	defer outFileWriter.Flush()
	inFileReader := bufio.NewReader(inFile)
	_, err = outFileWriter.WriteString("MSU1")
	if err != nil {
		print("problem writing output file\n")
		return
	}
	loopPointBytes := make([]byte, 4)
	binary.LittleEndian.PutUint32(loopPointBytes, loopPoint32)
	_, err = outFileWriter.Write(loopPointBytes)
	if err != nil {
		print("problem writing output file\n")
		return
	}
	for i := 0; i < 44; i++ {
		_, err := inFileReader.ReadByte()
		if err != nil {
			print("problem reading input file--malformed? (couldnt skip past headers)\n")
			return
		}
	}
	for b, err := inFileReader.ReadByte(); err == nil; b, err = inFileReader.ReadByte() {
		err = outFileWriter.WriteByte(b)
		if err != nil {
			print("problem writing output file\n")
			return
		}
	}
	print("done")
}
